@@ -79,7 +79,7 @@ class HomogeneousCoordinatesPoint(np.ndarray, metaclass=ABCMeta):
     @property
     def H(self):
         """ Point expressed in homogenous coordinates with an homogenous component equal to `1`.
-
+        
         Example:
         ```
         >>> p = Point3D(1,2,3)
@@ -103,11 +103,7 @@ class HomogeneousCoordinatesPoint(np.ndarray, metaclass=ABCMeta):
 
     # /!\ iter may conflict with numpy array getitem.
     def __iter__(self):
-        try:
-            return (self.__class__(self[:,i:i+1]) for i in range(self.shape[1]))
-        except IndexError as e:
-            print(self, self.shape)
-            raise e
+        return (self.__class__(self[:,i:i+1]) for i in range(self.shape[1]))
 
     def to_list(self):
         """ Transforms a single point to a python list.
